@@ -1,5 +1,5 @@
 <?php
-//VERSION=0.5
+//VERSION=0.6
 $info = get_token_info();
 
 $user = $info['email'];
@@ -67,7 +67,10 @@ function get_token_info()
 	}
 
 	//allow only 10 seconds to ues the token.
-	if ($file_data['created'] + 10 < time())
+	$timeout = 10;
+	if (isset($file_data['timeout']) && is_numeric($file_data['timeout']))
+		$timeout = (int)$file_data['timeout'];
+	if ($file_data['created'] + $timeout < time())
 		die_rm("token has expired", $token_file);
 
 	//delete token_file
